==> evince-0.5.2.tar.bz2: evince-0.5.2/shell/ev-marshal.h <==

#ifndef __ev_marshal_MARSHAL_H__
#define __ev_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:NONE (../../evince/shell/ev-marshal.list:1) */
#define ev_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID
#define ev_marshal_VOID__NONE	ev_marshal_VOID__VOID

/* VOID:OBJECT,OBJECT (../../evince/shell/ev-marshal.list:2) */
extern void ev_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);

/* VOID:ENUM,BOOLEAN (../../evince/shell/ev-marshal.list:3) */
extern void ev_marshal_VOID__ENUM_BOOLEAN (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
                                           const GValue *param_values,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);

/* BOOLEAN:STRING (../../evince/shell/ev-marshal.list:4) */
extern void ev_marshal_BOOLEAN__STRING (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
                                        const GValue *param_values,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);

G_END_DECLS

#endif /* __ev_marshal_MARSHAL_H__ */

==> evince-0.7.1.tar.bz2: evince-0.7.1/shell/ev-marshal.h <==

#ifndef __ev_marshal_MARSHAL_H__
#define __ev_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:NONE (./ev-marshal.list:1) */
#define ev_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID
#define ev_marshal_VOID__NONE	ev_marshal_VOID__VOID

/* VOID:OBJECT,OBJECT (./ev-marshal.list:2) */
extern void ev_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);

/* VOID:ENUM,BOOLEAN (./ev-marshal.list:3) */
extern void ev_marshal_VOID__ENUM_BOOLEAN (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
                                           const GValue *param_values,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);

/* BOOLEAN:STRING (./ev-marshal.list:4) */
extern void ev_marshal_BOOLEAN__STRING (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
                                        const GValue *param_values,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);

G_END_DECLS

#endif /* __ev_marshal_MARSHAL_H__ */
